# ifndef yyStrUnparse
# define yyStrUnparse

# if defined __STDC__ | defined __cplusplus
# define ARGS(parameters)	parameters
# else
# define ARGS(parameters)	()
# endif

# ifndef rbool
# define rbool char
# endif

# include "Tree.h"
# include "Definitions.h"

/* line 25 "StrUnparse.puma" */


typedef char* String;



extern void (* StrUnparse_Exit) ARGS ((void));

extern void StrUnparse ARGS ((String str, int len, tTree t));

extern void BeginStrUnparse ARGS ((void));
extern void CloseStrUnparse ARGS ((void));

# endif
